@@ -4,6 +4,8 @@
     icecream.enabled = TRUE,
     icecream.prefix = "ic|",
     icecream.output.function = NULL,
+    icecream.peeking.function = ic_autopeek,
+    icecream.max.lines = 1,
     icecream.arg.to.string.function = NULL,
     icecream.always.include.context = FALSE
   )
@@ -15,6 +17,8 @@
     icecream.enabled = NULL,
     icecream.prefix = NULL,
     icecream.output.function = NULL,
+    icecream.peeking.function = NULL,
+    icecream.max.lines = NULL,
     icecream.arg.to.string.function = NULL,
     icecream.always.include.context = NULL
   )
